defmodule Webmon.MonitorTest do
  use Webmon.DataCase

  alias Webmon.Monitor

  describe "websites" do
    alias Webmon.Monitor.Website

    import Webmon.MonitorFixtures

    @invalid_attrs %{name: nil, url: nil}

    test "list_websites/0 returns all websites" do
      website = website_fixture()
      assert Monitor.list_websites() == [website]
    end

    test "get_website!/1 returns the website with given id" do
      website = website_fixture()
      assert Monitor.get_website!(website.id) == website
    end

    test "create_website/1 with valid data creates a website" do
      valid_attrs = %{name: "some name", url: "some url"}

      assert {:ok, %Website{} = website} = Monitor.create_website(valid_attrs)
      assert website.name == "some name"
      assert website.url == "some url"
    end

    test "create_website/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Monitor.create_website(@invalid_attrs)
    end

    test "update_website/2 with valid data updates the website" do
      website = website_fixture()
      update_attrs = %{name: "some updated name", url: "some updated url"}

      assert {:ok, %Website{} = website} = Monitor.update_website(website, update_attrs)
      assert website.name == "some updated name"
      assert website.url == "some updated url"
    end

    test "update_website/2 with invalid data returns error changeset" do
      website = website_fixture()
      assert {:error, %Ecto.Changeset{}} = Monitor.update_website(website, @invalid_attrs)
      assert website == Monitor.get_website!(website.id)
    end

    test "delete_website/1 deletes the website" do
      website = website_fixture()
      assert {:ok, %Website{}} = Monitor.delete_website(website)
      assert_raise Ecto.NoResultsError, fn -> Monitor.get_website!(website.id) end
    end

    test "change_website/1 returns a website changeset" do
      website = website_fixture()
      assert %Ecto.Changeset{} = Monitor.change_website(website)
    end
  end
end
